@@ -1,6 +1,17 @@
 ## EM for Beta Mixture Models (BMM) with Nc components
 
-EM_bmm_ab <- function(x, Nc, mix_init, Ninit = 50, verbose = FALSE, Niter.max = 500, tol, Neps, eps = c(w = 0.005, a = 0.005, b = 0.005), constrain_gt1 = TRUE) {
+EM_bmm_ab <- function(
+  x,
+  Nc,
+  mix_init,
+  Ninit = 50,
+  verbose = FALSE,
+  Niter.max = 500,
+  tol,
+  Neps,
+  eps = c(w = 0.005, a = 0.005, b = 0.005),
+  constrain_gt1 = TRUE
+) {
   N <- length(x)
   assert_that(N + Nc >= Ninit)
 
@@ -11,12 +22,20 @@ EM_bmm_ab <- function(x, Nc, mix_init, Ninit = 50, verbose = FALSE, Niter.max =
   ## ensures proper handling during fit.
   x0 <- x == 0
   if (any(x0)) {
-    message("Detected ", sum(x0), " value(s) which are exactly 0.\nTo avoid numerical issues during EM such values are moved to smallest eps on machine.")
+    message(
+      "Detected ",
+      sum(x0),
+      " value(s) which are exactly 0.\nTo avoid numerical issues during EM such values are moved to smallest eps on machine."
+    )
     x[x0] <- .Machine$double.eps
   }
   x1 <- x == 1
   if (any(x1)) {
-    message("Detected ", sum(x1), " value(s) which are exactly 1.\nTo avoid numerical issues during EM such values are moved to one minus smallest eps on machine.")
+    message(
+      "Detected ",
+      sum(x1),
+      " value(s) which are exactly 1.\nTo avoid numerical issues during EM such values are moved to one minus smallest eps on machine."
+    )
     x[x1] <- 1 - .Machine$double.eps
   }
 
@@ -32,7 +51,10 @@ EM_bmm_ab <- function(x, Nc, mix_init, Ninit = 50, verbose = FALSE, Niter.max =
     ## abmEst[,1] <- 1/Nc
     ## assume that the sample is ordered randomly
     ind <- seq(1, N - Nc, length = Ninit)
-    knnInit <- list(mu = matrix(0, nrow = Nc, ncol = 1), p = rep(1 / Nc, times = Nc))
+    knnInit <- list(
+      mu = matrix(0, nrow = Nc, ncol = 1),
+      p = rep(1 / Nc, times = Nc)
+    )
     for (k in seq(Nc)) {
       knnInit$mu[k, 1] <- mean(x[ind + k - 1])
     }
@@ -52,7 +74,11 @@ EM_bmm_ab <- function(x, Nc, mix_init, Ninit = 50, verbose = FALSE, Niter.max =
     cmin <- which.min(KNN$p)
     muInit[cmin] <- sum(KNN$p * KNN$center)
     ## muInit[cmin] <- mean(x) ## could be considered here
-    nInit[cmin] <- pmax(muInit[cmin] * (1 - muInit[cmin]) / var(x) - 1, 1, na.rm = TRUE)
+    nInit[cmin] <- pmax(
+      muInit[cmin] * (1 - muInit[cmin]) / var(x) - 1,
+      1,
+      na.rm = TRUE
+    )
     ## Nmax <- max(2, max(nInit))
     ## ensure n is positive for each cluster; if this is not the
     ## case, sample uniformly from the range of n we have
@@ -126,7 +152,11 @@ EM_bmm_ab <- function(x, Nc, mix_init, Ninit = 50, verbose = FALSE, Niter.max =
   traceMix <- list()
   traceLli <- c()
   Dlli <- Inf
-  runMixPar <- array(-Inf, dim = c(Neps, 3, Nc), dimnames = list(NULL, rownames(mixEstPar), NULL))
+  runMixPar <- array(
+    -Inf,
+    dim = c(Neps, 3, Nc),
+    dimnames = list(NULL, rownames(mixEstPar), NULL)
+  )
   runOrder <- 0:(Neps - 1)
   Npar <- Nc + 2 * Nc
   if (Nc == 1) Npar <- Npar - 1
@@ -160,10 +190,14 @@ EM_bmm_ab <- function(x, Nc, mix_init, Ninit = 50, verbose = FALSE, Niter.max =
 
       trig_n <- trigamma(n)
 
-      grad1 <- 2 * sqTerm1 * (trigamma(ab[1]) * ab[1] - trig_n * ab[1]) -
+      grad1 <- 2 *
+        sqTerm1 *
+        (trigamma(ab[1]) * ab[1] - trig_n * ab[1]) -
         2 * sqTerm2 * (trig_n * ab[1])
 
-      grad2 <- -2 * sqTerm1 * (trig_n * ab[2]) +
+      grad2 <- -2 *
+        sqTerm1 *
+        (trig_n * ab[2]) +
         2 * sqTerm2 * (trigamma(ab[2]) * ab[2] - trig_n * ab[2])
 
       c(grad1, grad2)
@@ -182,7 +216,14 @@ EM_bmm_ab <- function(x, Nc, mix_init, Ninit = 50, verbose = FALSE, Niter.max =
     a <- mixEst[2, ]
     b <- mixEst[3, ]
     ## lli <- sweep( sweep(Lx, 2, a - 1, "*", check.margin=FALSE) + sweep(LxC, 2, b - 1, "*", check.margin=FALSE), 2, log(w) + lgamma(a + b) - lgamma(a) - lgamma(b), "+", check.margin=FALSE)
-    lli <- sweep(sweep(Lx, 2, a - 1, "*", check.margin = FALSE) + sweep(LxC, 2, b - 1, "*", check.margin = FALSE), 2, log(w) - lbeta(a, b), "+", check.margin = FALSE)
+    lli <- sweep(
+      sweep(Lx, 2, a - 1, "*", check.margin = FALSE) +
+        sweep(LxC, 2, b - 1, "*", check.margin = FALSE),
+      2,
+      log(w) - lbeta(a, b),
+      "+",
+      check.margin = FALSE
+    )
     ## lli <- t(matrix(log(mixEst[1,]) + dbeta(xRep, mixEst[2,], mixEst[3,], log=TRUE), nrow=Nc))
 
     ## ensure that the log-likelihood does not go out of numerical
@@ -202,15 +243,36 @@ EM_bmm_ab <- function(x, Nc, mix_init, Ninit = 50, verbose = FALSE, Niter.max =
       Dlli <- (traceLli[iter + 1] - traceLli[iter - 1]) / 2
     }
     if (Nc > 1) {
-      smean <- apply(runMixPar[order(runOrder), , , drop = FALSE], c(2, 3), function(x) mean(abs(diff(x))))
+      smean <- apply(
+        runMixPar[order(runOrder), , , drop = FALSE],
+        c(2, 3),
+        function(x) mean(abs(diff(x)))
+      )
       eps.converged <- sum(sweep(smean, 1, eps, "-") < 0)
     } else {
-      smean <- apply(runMixPar[order(runOrder), -1, , drop = FALSE], c(2, 3), function(x) mean(abs(diff(x))))
+      smean <- apply(
+        runMixPar[order(runOrder), -1, , drop = FALSE],
+        c(2, 3),
+        function(x) mean(abs(diff(x)))
+      )
       eps.converged <- sum(sweep(smean, 1, eps[-1], "-") < 0)
     }
     if (is.na(eps.converged)) eps.converged <- 0
     if (verbose) {
-      message("Iteration ", iter, ": log-likelihood = ", lliCur, "; Dlli = ", Dlli, "; converged = ", eps.converged, " / ", Npar, "\n", sep = "")
+      message(
+        "Iteration ",
+        iter,
+        ": log-likelihood = ",
+        lliCur,
+        "; Dlli = ",
+        Dlli,
+        "; converged = ",
+        eps.converged,
+        " / ",
+        Npar,
+        "\n",
+        sep = ""
+      )
     }
     if (checkTol & Dlli < tol) {
       break
@@ -250,7 +312,13 @@ EM_bmm_ab <- function(x, Nc, mix_init, Ninit = 50, verbose = FALSE, Niter.max =
       ## Default would be Nelder-Mead
       Lest <- optim(theta, bmm_ml(c1[i], c2[i]))
       if (Lest$convergence != 0 & Lest$value > 1E-4) {
-        warning("Warning: Component", i, "in iteration", iter, "had convergence problems!")
+        warning(
+          "Warning: Component",
+          i,
+          "in iteration",
+          iter,
+          "had convergence problems!"
+        )
       }
       if (constrain_gt1) {
         mixEst[2:3, i] <- 1 + pmax(exp(Lest$par), c(1E-8, 1E-8))
@@ -297,6 +365,11 @@ EM_bmm_ab <- function(x, Nc, mix_init, Ninit = 50, verbose = FALSE, Niter.max =
 
 #' @export
 print.EMbmm <- function(x, ...) {
-  cat("EM for Beta Mixture Model\nLog-Likelihood = ", logLik(x), "\n\n", sep = "")
+  cat(
+    "EM for Beta Mixture Model\nLog-Likelihood = ",
+    logLik(x),
+    "\n\n",
+    sep = ""
+  )
   NextMethod()
 }
