@@ -11,14 +11,21 @@
 dBetaBinomial <- function(r, n, a, b, log = FALSE) {
   assert_integerish(n, lower = 0L, any.missing = FALSE)
   assert_integerish(r, lower = 0L, upper = max(n), any.missing = FALSE)
-  p <- lgamma(n + 1) - lgamma(r + 1) - lgamma(n - r + 1) + lgamma(a + b) - lgamma(a) - lgamma(b) + lgamma(a + r) + lgamma(b + n - r) - lgamma(a + b + n)
+  p <- lgamma(n + 1) -
+    lgamma(r + 1) -
+    lgamma(n - r + 1) +
+    lgamma(a + b) -
+    lgamma(a) -
+    lgamma(b) +
+    lgamma(a + r) +
+    lgamma(b + n - r) -
+    lgamma(a + b + n)
   if (log) {
     return(p)
   }
   exp(p)
 }
 
-
 ## pBetaBinomial <- function(r, n, a, b, lower.tail=TRUE, log.p=FALSE) {
 ##    return(.pBetaBinomial(r, n, a, b, lower.tail, log.p))
 ## }
