@@ -16,7 +16,13 @@
 #' @param Lpupper logit of upper cumulative density
 #'
 #' @keywords internal
-integrate_density_log <- function(log_integrand, mix, Lplower = -Inf, Lpupper = Inf, eps = getOption("RBesT.integrate_prob_eps", 1E-6)) {
+integrate_density_log <- function(
+  log_integrand,
+  mix,
+  Lplower = -Inf,
+  Lpupper = Inf,
+  eps = getOption("RBesT.integrate_prob_eps", 1E-6)
+) {
   .integrand_comp_logit <- function(mix_comp) {
     function(l) {
       u <- inv_logit(l)
@@ -35,19 +41,44 @@ integrate_density_log <- function(log_integrand, mix, Lplower = -Inf, Lpupper =
   ## issues.
   lower <- inv_logit(Lplower)
   upper <- inv_logit(Lpupper)
-  return(sum(vapply(1:Nc, function(comp) {
-    mix_comp <- mix[[comp, rescale = TRUE]]
-    fn_integrand_comp_logit <- .integrand_comp_logit(mix_comp)
-    if (all(!is.na(fn_integrand_comp_logit(c(Lplower, Lpupper))))) {
-      return(.integrate(fn_integrand_comp_logit, Lplower, Lpupper))
-    }
-    lower_comp <- ifelse(Lplower == -Inf, qmix(mix_comp, eps), qmix(mix_comp, lower))
-    upper_comp <- ifelse(Lpupper == Inf, qmix(mix_comp, 1 - eps), qmix(mix_comp, upper))
-    return(.integrate(function(x) exp(log_integrand(x) + dmix(mix_comp, x, log = TRUE)), lower_comp, upper_comp))
-  }, c(0.1)) * mix[1, ]))
+  return(sum(
+    vapply(
+      1:Nc,
+      function(comp) {
+        mix_comp <- mix[[comp, rescale = TRUE]]
+        fn_integrand_comp_logit <- .integrand_comp_logit(mix_comp)
+        if (all(!is.na(fn_integrand_comp_logit(c(Lplower, Lpupper))))) {
+          return(.integrate(fn_integrand_comp_logit, Lplower, Lpupper))
+        }
+        lower_comp <- ifelse(
+          Lplower == -Inf,
+          qmix(mix_comp, eps),
+          qmix(mix_comp, lower)
+        )
+        upper_comp <- ifelse(
+          Lpupper == Inf,
+          qmix(mix_comp, 1 - eps),
+          qmix(mix_comp, upper)
+        )
+        return(.integrate(
+          function(x) exp(log_integrand(x) + dmix(mix_comp, x, log = TRUE)),
+          lower_comp,
+          upper_comp
+        ))
+      },
+      c(0.1)
+    ) *
+      mix[1, ]
+  ))
 }
 
-integrate_density <- function(integrand, mix, Lplower = -Inf, Lpupper = Inf, eps = getOption("RBesT.integrate_prob_eps", 1E-6)) {
+integrate_density <- function(
+  integrand,
+  mix,
+  Lplower = -Inf,
+  Lpupper = Inf,
+  eps = getOption("RBesT.integrate_prob_eps", 1E-6)
+) {
   .integrand_comp_logit <- function(mix_comp) {
     function(l) {
       u <- inv_logit(l)
@@ -61,25 +92,45 @@ integrate_density <- function(integrand, mix, Lplower = -Inf, Lpupper = Inf, eps
   lower <- inv_logit(Lplower)
   upper <- inv_logit(Lpupper)
 
-  return(sum(vapply(1:Nc, function(comp) {
-    mix_comp <- mix[[comp, rescale = TRUE]]
-    ## ensure that the integrand is defined at the boundaries...
-    fn_integrand_comp_logit <- .integrand_comp_logit(mix_comp)
-    if (all(!is.na(fn_integrand_comp_logit(c(Lplower, Lpupper))))) {
-      return(.integrate(fn_integrand_comp_logit, Lplower, Lpupper))
-    }
-    ## ... otherwise we avoid the boundaries by eps prob density:
-    lower_comp <- ifelse(Lplower == -Inf, qmix(mix_comp, eps), qmix(mix_comp, lower))
-    upper_comp <- ifelse(Lpupper == Inf, qmix(mix_comp, 1 - eps), qmix(mix_comp, upper))
-    return(.integrate(function(x) integrand(x) * dmix(mix_comp, x), lower_comp, upper_comp))
-  }, c(0.1)) * mix[1, ]))
+  return(sum(
+    vapply(
+      1:Nc,
+      function(comp) {
+        mix_comp <- mix[[comp, rescale = TRUE]]
+        ## ensure that the integrand is defined at the boundaries...
+        fn_integrand_comp_logit <- .integrand_comp_logit(mix_comp)
+        if (all(!is.na(fn_integrand_comp_logit(c(Lplower, Lpupper))))) {
+          return(.integrate(fn_integrand_comp_logit, Lplower, Lpupper))
+        }
+        ## ... otherwise we avoid the boundaries by eps prob density:
+        lower_comp <- ifelse(
+          Lplower == -Inf,
+          qmix(mix_comp, eps),
+          qmix(mix_comp, lower)
+        )
+        upper_comp <- ifelse(
+          Lpupper == Inf,
+          qmix(mix_comp, 1 - eps),
+          qmix(mix_comp, upper)
+        )
+        return(.integrate(
+          function(x) integrand(x) * dmix(mix_comp, x),
+          lower_comp,
+          upper_comp
+        ))
+      },
+      c(0.1)
+    ) *
+      mix[1, ]
+  ))
 }
 
 .integrate <- function(integrand, lower, upper) {
   integrate_args_user <- getOption("RBesT.integrate_args", list())
   args <- modifyList(
     list(
-      lower = lower, upper = upper,
+      lower = lower,
+      upper = upper,
       rel.tol = .Machine$double.eps^0.25,
       abs.tol = .Machine$double.eps^0.25,
       subdivisions = 1000,
@@ -88,7 +139,8 @@ integrate_density <- function(integrand, mix, Lplower = -Inf, Lpupper = Inf, eps
     integrate_args_user
   )
 
-  integrate(integrand,
+  integrate(
+    integrand,
     lower = args$lower,
     upper = args$upper,
     rel.tol = args$rel.tol,
