@@ -3,41 +3,41 @@
 #' Add a non-informative component to a mixture prior.
 #'
 #' @param priormix orior (mixture of conjugate distributions).
-#' @param weight weight given to the non-informative component (0 < \code{weight} < 1).
+#' @param weight weight given to the non-informative component (0 < `weight` < 1).
 #' @param mean mean of the non-informative component. It is recommended to set this parameter explicitly.
 #' @param n number of observations the non-informative prior
 #' corresponds to, defaults to 1.
 #' @param ... optional arguments are ignored.
 #'
 #' @details It is recommended to robustify informative priors derived
-#' with \code{\link{gMAP}} using unit-information priors . This
+#' with [gMAP()] using unit-information priors . This
 #' protects against prior-data conflict, see for example
-#' \emph{Schmidli et al., 2015}.
+#' *Schmidli et al., 2015*.
 #'
 #' The procedure can be used with beta, gamma and normal mixture
-#' priors. A unit-information prior (see \emph{Kass and Wasserman,
-#' 1995}) corresponds to a prior which represents the observation of
+#' priors. A unit-information prior (see *Kass and Wasserman,
+#' 1995*) corresponds to a prior which represents the observation of
 #' n=1 at the null hypothesis. As the null is problem dependent we
-#' \emph{strongly recommend} to make use of the \code{mean} argument
+#' *strongly recommend* to make use of the `mean` argument
 #' accordingly. See below for the definition of the default mean.
 #'
-#' The weights of the mixture priors are rescaled to \code{(1-weight)}
-#' while the non-informative prior is assigned the \code{weight}
+#' The weights of the mixture priors are rescaled to `(1-weight)`
+#' while the non-informative prior is assigned the `weight`
 #' given.
 #'
 #' @return New mixture with an extra non-informative component named
-#' \code{robust}.
+#' `robust`.
 #'
 #' @references Schmidli H, Gsteiger S, Roychoudhury S, O'Hagan A,
 #' Spiegelhalter D, Neuenschwander B.  Robust meta-analytic-predictive
 #' priors in clinical trials with historical control information.
-#' \emph{Biometrics} 2014;70(4):1023-1032.
+#' *Biometrics* 2014;70(4):1023-1032.
 #'
 #' Kass RE, Wasserman L A Reference Bayesian Test for Nested
-#' Hypotheses and its Relationship to the Schwarz Criterion \emph{J
-#' Amer Statist Assoc} 1995; 90(431):928-934.
+#' Hypotheses and its Relationship to the Schwarz Criterion *J
+#' Amer Statist Assoc* 1995; 90(431):928-934.
 #'
-#' @seealso \code{\link{mixcombine}}
+#' @seealso [mixcombine()]
 #'
 #' @examples
 #' bmix <- mixbeta(inf1 = c(0.2, 8, 3), inf2 = c(0.8, 10, 2))
@@ -62,14 +62,15 @@
 robustify <- function(priormix, weight, mean, n = 1, ...) UseMethod("robustify")
 
 #' @export
-robustify.default <- function(priormix, weight, mean, n = 1, ...) "Unknown density"
+robustify.default <- function(priormix, weight, mean, n = 1, ...)
+  "Unknown density"
 
-#' @describeIn robustify The default \code{mean} is set to 1/2 which
+#' @describeIn robustify The default `mean` is set to 1/2 which
 #' represents no difference between the occurrence rates for one of the
-#' two outcomes. As the uniform \code{Beta(1,1)} is more appropriate in
-#' practical applications, \code{RBesT} uses \code{n+1} as the sample
+#' two outcomes. As the uniform `Beta(1,1)` is more appropriate in
+#' practical applications, `RBesT` uses `n+1` as the sample
 #' size such that the default robust prior is the uniform instead of
-#' the \code{Beta(1/2,1/2)} which strictly defined would be the unit
+#' the `Beta(1/2,1/2)` which strictly defined would be the unit
 #' information prior in this case.
 #' @export
 robustify.betaMix <- function(priormix, weight, mean, n = 1, ...) {
@@ -84,7 +85,7 @@ robustify.betaMix <- function(priormix, weight, mean, n = 1, ...) {
   mixcombine(priormix, rob, weight = c(1 - weight, weight))
 }
 
-#' @describeIn robustify The default \code{mean} is set to the mean of the
+#' @describeIn robustify The default `mean` is set to the mean of the
 #' prior mixture. It is strongly recommended to explicitly set the
 #' mean to the location of the null hypothesis.
 #' @export
@@ -93,19 +94,27 @@ robustify.gammaMix <- function(priormix, weight, mean, n = 1, ...) {
   assert_number(n, lower = 0, finite = TRUE)
   if (missing(mean)) {
     s <- summary(priormix)
-    message(paste("Using default mean for robust component; the mean of the prior which is", s["mean"], "."))
+    message(paste(
+      "Using default mean for robust component; the mean of the prior which is",
+      s["mean"],
+      "."
+    ))
     mean <- s["mean"]
   }
   assert_number(mean, lower = 0, finite = TRUE)
-  rob <- mixgamma(robust = c(1, mean, n), param = "mn", likelihood = likelihood(priormix))
+  rob <- mixgamma(
+    robust = c(1, mean, n),
+    param = "mn",
+    likelihood = likelihood(priormix)
+  )
   mixcombine(priormix, rob, weight = c(1 - weight, weight))
 }
 
-#' @describeIn robustify The default \code{mean} is set to the mean
+#' @describeIn robustify The default `mean` is set to the mean
 #' of the prior mixture. It is strongly recommended to explicitly set
 #' the mean to the location of the null hypothesis, which is very
 #' often equal to 0. It is also recommended to explicitly set the
-#' sampling standard deviation using the \code{sigma} argument.
+#' sampling standard deviation using the `sigma` argument.
 #' @param sigma Sampling standard deviation for the case of Normal
 #' mixtures.
 #' @export
@@ -114,7 +123,11 @@ robustify.normMix <- function(priormix, weight, mean, n = 1, ..., sigma) {
   assert_number(n, lower = 0, finite = TRUE)
   if (missing(mean)) {
     s <- summary(priormix)
-    message(paste("Using default mean for robust component; the mean of the prior which is", s["mean"], "."))
+    message(paste(
+      "Using default mean for robust component; the mean of the prior which is",
+      s["mean"],
+      "."
+    ))
     mean <- s["mean"]
   }
   assert_number(mean, finite = TRUE)
