@@ -6,5 +6,13 @@
 
 .onAttach <- function(...) {
   ver <- utils::packageVersion("RBesT")
-  packageStartupMessage("This is RBesT version ", ver, " (released ", format(pkg_create_date, "%F"), ", git-sha ", pkg_sha, ")")
+  packageStartupMessage(
+    "This is RBesT version ",
+    ver,
+    " (released ",
+    format(pkg_create_date, "%F"),
+    ", git-sha ",
+    pkg_sha,
+    ")"
+  )
 }
