@@ -33,13 +33,33 @@ normMixWeak <- mixnorm(c(0.2, 0, 2), c(0.8, 1, 2), c(0, 0, 1), sigma = 1)
 
 ## tests the quantile and distribution function against simulated
 ## samples when using brms prior sampling as reference
-mixstanvar_simul_test <- function(mix,
-                                  brms_args,
-                                  eps, qtest, ptest = seq(0.2, 0.8, by = 0.2)) {
+mixstanvar_simul_test <- function(
+  mix,
+  brms_args,
+  eps,
+  qtest,
+  ptest = seq(0.2, 0.8, by = 0.2)
+) {
   skip_on_cran()
   skip_on_ci()
-  capture.output(brms_prior <- do.call(brms::brm, c(brms_args, list(seed = 1423545, refresh = 0, sample_prior = "only", stanvars = mixstanvar(prior = mix)))))
-  samp <- as.numeric(brms::as_draws_matrix(brms_prior, variable = "b_Intercept")[, 1])
+  capture.output(
+    brms_prior <- do.call(
+      brms::brm,
+      c(
+        brms_args,
+        list(
+          seed = 1423545,
+          refresh = 0,
+          sample_prior = "only",
+          stanvars = mixstanvar(prior = mix)
+        )
+      )
+    )
+  )
+  samp <- as.numeric(brms::as_draws_matrix(
+    brms_prior,
+    variable = "b_Intercept"
+  )[, 1])
   qtest_samp <- quantile(samp, ptest)
   qref_qmix <- qmix(mix, ptest)
   res_quants <- abs(qref_qmix - qtest_samp)
@@ -51,9 +71,20 @@ mixstanvar_simul_test <- function(mix,
 }
 
 
-mixstanvar_test <- function(mix,
-                            brms_args) {
-  brms_prior_empty <- do.call(brms::brm, c(brms_args, list(seed = 1423545, refresh = 0, sample_prior = "only", stanvars = mixstanvar(prior = mix), empty = TRUE)))
+mixstanvar_test <- function(mix, brms_args) {
+  brms_prior_empty <- do.call(
+    brms::brm,
+    c(
+      brms_args,
+      list(
+        seed = 1423545,
+        refresh = 0,
+        sample_prior = "only",
+        stanvars = mixstanvar(prior = mix),
+        empty = TRUE
+      )
+    )
+  )
   mix_class <- gsub("Mix$", "", class(mix)[1])
   stan_dist_lpdf <- paste0("mix", mix_class, "_lpdf")
   stan_dist_lcdf <- paste0("mix", mix_class, "_lcdf")
@@ -61,10 +92,22 @@ mixstanvar_test <- function(mix,
   stan_dist_cdf <- paste0("mix", mix_class, "_cdf")
   ## look for the declared density in Stan
   stan_code <- brms::stancode(brms_prior_empty)
-  expect_true(grep(stan_dist_lpdf, stan_code) == 1, info = "Looking for declared Stan mixture density pdf in generated brms Stan code.")
-  expect_true(grep(stan_dist_lcdf, stan_code) == 1, info = "Looking for declared Stan mixture density cdf in generated brms Stan code.")
-  expect_true(grep(stan_dist_lccdf, stan_code) == 1, info = "Looking for declared Stan mixture density ccdf in generated brms Stan code.")
-  expect_true(grep(stan_dist_cdf, stan_code) == 1, info = "Looking for declared Stan mixture density natural scale cdf in generated brms Stan code.")
+  expect_true(
+    grep(stan_dist_lpdf, stan_code) == 1,
+    info = "Looking for declared Stan mixture density pdf in generated brms Stan code."
+  )
+  expect_true(
+    grep(stan_dist_lcdf, stan_code) == 1,
+    info = "Looking for declared Stan mixture density cdf in generated brms Stan code."
+  )
+  expect_true(
+    grep(stan_dist_lccdf, stan_code) == 1,
+    info = "Looking for declared Stan mixture density ccdf in generated brms Stan code."
+  )
+  expect_true(
+    grep(stan_dist_cdf, stan_code) == 1,
+    info = "Looking for declared Stan mixture density natural scale cdf in generated brms Stan code."
+  )
   ## now check for the mixture being passed to Stan as data
   stan_data <- brms::standata(brms_prior_empty)
   for (i in 1:3) {
@@ -74,7 +117,11 @@ mixstanvar_test <- function(mix,
 }
 
 brms_beta_args <- list(
-  formula = brms::bf(r | trials(n) ~ 1, family = brms::brmsfamily("binomial", link = "identity"), center = FALSE),
+  formula = brms::bf(
+    r | trials(n) ~ 1,
+    family = brms::brmsfamily("binomial", link = "identity"),
+    center = FALSE
+  ),
   data = data.frame(r = 0, n = 0),
   prior = brms::prior(mixbeta(prior_w, prior_a, prior_b), coef = Intercept)
 )
@@ -93,9 +140,18 @@ test_that("Beta mixture prior is declared correctly in brms generated model and
 })
 
 brms_beta_trunc_args <- list(
-  formula = brms::bf(r | trials(n) ~ 1, family = brms::brmsfamily("binomial", link = "identity"), center = FALSE),
+  formula = brms::bf(
+    r | trials(n) ~ 1,
+    family = brms::brmsfamily("binomial", link = "identity"),
+    center = FALSE
+  ),
   data = data.frame(r = 0, n = 0),
-  prior = brms::prior(mixbeta(prior_w, prior_a, prior_b), class = b, lb = 0.1, ub = 0.9)
+  prior = brms::prior(
+    mixbeta(prior_w, prior_a, prior_b),
+    class = b,
+    lb = 0.1,
+    ub = 0.9
+  )
 )
 test_that("Beta (truncated) prior is declared correctly in brms generated model and data", {
   mixstanvar_test(beta, brms_beta_trunc_args)
@@ -105,9 +161,14 @@ test_that("Beta mixture (truncated) prior is declared correctly in brms generate
 })
 
 brms_normal_args <- list(
-  formula = brms::bf(y ~ 1, family = brms::brmsfamily("gaussian", link = "identity"), center = FALSE),
+  formula = brms::bf(
+    y ~ 1,
+    family = brms::brmsfamily("gaussian", link = "identity"),
+    center = FALSE
+  ),
   data = data.frame(y = 0),
-  prior = brms::prior(mixnorm(prior_w, prior_m, prior_s), coef = Intercept) + brms::prior(constant(1), class = sigma)
+  prior = brms::prior(mixnorm(prior_w, prior_m, prior_s), coef = Intercept) +
+    brms::prior(constant(1), class = sigma)
 )
 test_that("Normal quantiles are correct for brms sampled prior", {
   mixstanvar_simul_test(norm, brms_normal_args, eps, c(-1, 0))
@@ -116,16 +177,32 @@ test_that("Normal prior is declared correctly in brms generated model and data",
   mixstanvar_test(norm, brms_normal_args)
 })
 test_that("Normal mixture quantiles are correct for brms sampled prior", {
-  mixstanvar_simul_test(normMix, brms_normal_args, eps, c(2, 1), ptest = c(0.3, 0.5, 0.7))
+  mixstanvar_simul_test(
+    normMix,
+    brms_normal_args,
+    eps,
+    c(2, 1),
+    ptest = c(0.3, 0.5, 0.7)
+  )
 })
 test_that("Normal mixture prior is declared correctly in brms generated model and data", {
   mixstanvar_test(normMix, brms_normal_args)
 })
 
 brms_normal_trunc_args <- list(
-  formula = brms::bf(y ~ 1, family = brms::brmsfamily("gaussian", link = "identity"), center = FALSE),
+  formula = brms::bf(
+    y ~ 1,
+    family = brms::brmsfamily("gaussian", link = "identity"),
+    center = FALSE
+  ),
   data = data.frame(y = 0),
-  prior = brms::prior(mixnorm(prior_w, prior_m, prior_s), class = b, lb = -5, ub = 5) + brms::prior(constant(1), class = sigma)
+  prior = brms::prior(
+    mixnorm(prior_w, prior_m, prior_s),
+    class = b,
+    lb = -5,
+    ub = 5
+  ) +
+    brms::prior(constant(1), class = sigma)
 )
 test_that("Normal (truncated) prior is declared correctly in brms generated model and data", {
   mixstanvar_test(norm, brms_normal_trunc_args)
@@ -135,9 +212,14 @@ test_that("Normal mixture (truncated) prior is declared correctly in brms genera
 })
 
 brms_gamma_args <- list(
-  formula = brms::bf(y ~ 1, family = brms::brmsfamily("gaussian", link = "identity"), center = FALSE),
+  formula = brms::bf(
+    y ~ 1,
+    family = brms::brmsfamily("gaussian", link = "identity"),
+    center = FALSE
+  ),
   data = data.frame(y = 1),
-  prior = brms::prior(mixgamma(prior_w, prior_a, prior_b), coef = Intercept) + brms::prior(constant(1), class = sigma)
+  prior = brms::prior(mixgamma(prior_w, prior_a, prior_b), coef = Intercept) +
+    brms::prior(constant(1), class = sigma)
 )
 
 test_that("Gamma quantiles are correct for brms sampled prior", {
@@ -147,16 +229,32 @@ test_that("Gamma prior is declared correctly in brms generated model and data",
   mixstanvar_test(gamma, brms_gamma_args)
 })
 test_that("Gamma mixture quantile function is correct for brms sampled prior", {
-  mixstanvar_simul_test(gammaMix, brms_gamma_args, eps, c(2, 7), ptest = seq(0.2, 0.8, by = 0.2))
+  mixstanvar_simul_test(
+    gammaMix,
+    brms_gamma_args,
+    eps,
+    c(2, 7),
+    ptest = seq(0.2, 0.8, by = 0.2)
+  )
 })
 test_that("Gamma mixture prior is declared correctly in brms generated model and data", {
   mixstanvar_test(gammaMix, brms_gamma_args)
 })
 
 brms_gamma_trunc_args <- list(
-  formula = brms::bf(y ~ 1, family = brms::brmsfamily("gaussian", link = "identity"), center = FALSE),
+  formula = brms::bf(
+    y ~ 1,
+    family = brms::brmsfamily("gaussian", link = "identity"),
+    center = FALSE
+  ),
   data = data.frame(y = 1),
-  prior = brms::prior(mixgamma(prior_w, prior_a, prior_b), class = b, lb = 0.1, ub = 10) + brms::prior(constant(1), class = sigma)
+  prior = brms::prior(
+    mixgamma(prior_w, prior_a, prior_b),
+    class = b,
+    lb = 0.1,
+    ub = 10
+  ) +
+    brms::prior(constant(1), class = sigma)
 )
 
 test_that("Gamma (truncated) prior is declared correctly in brms generated model and data", {
@@ -177,13 +275,33 @@ KLdiv_mvnorm <- function(m_1, sigma_1, m_2, sigma_2) {
   m_delta <- (m_2 - m_1)
   inv_sigma_2 <- solve(sigma_2)
   p <- length(m_1)
-  0.5 * (t(m_delta) %*% inv_sigma_2 %*% m_delta + sum(diag(inv_sigma_2 %*% sigma_1)) - log(det(sigma_1)) + log(det(sigma_2)) - p)
+  0.5 *
+    (t(m_delta) %*%
+      inv_sigma_2 %*%
+      m_delta +
+      sum(diag(inv_sigma_2 %*% sigma_1)) -
+      log(det(sigma_1)) +
+      log(det(sigma_2)) -
+      p)
 }
 
 mixstanvar_simul_mv_test <- function(mvmix, brms_args, eps) {
   skip_on_cran()
   skip_on_ci()
-  capture.output(brms_prior <- do.call(brms::brm, c(brms_args, list(seed = 1423545, refresh = 0, sample_prior = "only", stanvars = mixstanvar(prior = mvmix)))))
+  capture.output(
+    brms_prior <- do.call(
+      brms::brm,
+      c(
+        brms_args,
+        list(
+          seed = 1423545,
+          refresh = 0,
+          sample_prior = "only",
+          stanvars = mixstanvar(prior = mvmix)
+        )
+      )
+    )
+  )
   samp <- brms::as_draws_matrix(brms_prior, variable = "^b_", regex = TRUE)
   samp_m <- colMeans(samp)
   samp_sigma <- cov(samp)
@@ -193,12 +311,26 @@ mixstanvar_simul_mv_test <- function(mvmix, brms_args, eps) {
   expect_true(abs(kl) < eps)
 }
 
-mixstanvar_test_mvnormMix <- function(mix,
-                                      brms_args) {
-  brms_prior_empty <- do.call(brms::brm, c(brms_args, list(seed = 1423545, refresh = 0, sample_prior = "only", stanvars = mixstanvar(prior = mix), empty = TRUE)))
+mixstanvar_test_mvnormMix <- function(mix, brms_args) {
+  brms_prior_empty <- do.call(
+    brms::brm,
+    c(
+      brms_args,
+      list(
+        seed = 1423545,
+        refresh = 0,
+        sample_prior = "only",
+        stanvars = mixstanvar(prior = mix),
+        empty = TRUE
+      )
+    )
+  )
   stan_dist <- paste0("mix", gsub("Mix$", "", class(mix)[1]), "_lpdf")
   ## look for the declared density in Stan
-  expect_true(grep(stan_dist, brms::stancode(brms_prior_empty)) == 1, info = "Looking for declared Stan mixture density in generated brms Stan code.")
+  expect_true(
+    grep(stan_dist, brms::stancode(brms_prior_empty)) == 1,
+    info = "Looking for declared Stan mixture density in generated brms Stan code."
+  )
   ## now check for the mixture being passed to Stan as data
   stan_data <- brms::standata(brms_prior_empty)
   ## number of mixture components
@@ -216,7 +348,10 @@ mixstanvar_test_mvnormMix <- function(mix,
     S_c <- matrix(stan_data$prior_sigma[i, , , drop = FALSE], p, p)
     expect_equal(sqrt(diag(S_c)), unname(mix[(p + 2):(1 + 2 * p), i]))
     Rho_c <- cov2cor(S_c)
-    expect_equal(Rho_c[lower.tri(Rho_c)], unname(mix[(1 + 2 * p + 1):nrow(mix), i]))
+    expect_equal(
+      Rho_c[lower.tri(Rho_c)],
+      unname(mix[(1 + 2 * p + 1):nrow(mix), i])
+    )
   }
 }
 
@@ -230,21 +365,25 @@ zero <- rep(0, p)
 m1 <- 0:3
 m2 <- 1:4
 
-mvnorm_single_4 <- mixmvnorm(c(1, m1, 5),
-  param = "mn", sigma = S
-)
+mvnorm_single_4 <- mixmvnorm(c(1, m1, 5), param = "mn", sigma = S)
 
-mvnorm_heavy_4 <- mixmvnorm(c(0.5, m1, 0.25),
+mvnorm_heavy_4 <- mixmvnorm(
+  c(0.5, m1, 0.25),
   c(0.5, m2, 5),
-  param = "mn", sigma = S
+  param = "mn",
+  sigma = S
 )
 
 
-
 brms_mvn_4_args <- list(
-  formula = brms::bf(y ~ 1 + l1 + l2 + l3, family = brms::brmsfamily("gaussian", link = "identity"), center = FALSE),
+  formula = brms::bf(
+    y ~ 1 + l1 + l2 + l3,
+    family = brms::brmsfamily("gaussian", link = "identity"),
+    center = FALSE
+  ),
   data = data.frame(y = 1, l1 = 0, l2 = 0, l3 = 0),
-  prior = brms::prior(mixmvnorm(prior_w, prior_m, prior_sigma_L), class = b) + brms::prior(constant(1), class = sigma)
+  prior = brms::prior(mixmvnorm(prior_w, prior_m, prior_sigma_L), class = b) +
+    brms::prior(constant(1), class = sigma)
 )
 
 test_that("Multivariate normal (4D) is correct for brms sampled prior", {
@@ -260,20 +399,29 @@ test_that("Multivariate normal with heavy (4D) tails is declared correctly in br
   mixstanvar_test_mvnormMix(mvnorm_heavy_4, brms_mvn_4_args)
 })
 
-mvnorm_single_2 <- mixmvnorm(c(1, m1[1:2], 5),
-  param = "mn", sigma = S[1:2, 1:2]
+mvnorm_single_2 <- mixmvnorm(
+  c(1, m1[1:2], 5),
+  param = "mn",
+  sigma = S[1:2, 1:2]
 )
 
 
-mvnorm_heavy_2 <- mixmvnorm(c(0.5, m1[1:2], 0.25),
+mvnorm_heavy_2 <- mixmvnorm(
+  c(0.5, m1[1:2], 0.25),
   c(0.5, m2[1:2], 5),
-  param = "mn", sigma = S[1:2, 1:2]
+  param = "mn",
+  sigma = S[1:2, 1:2]
 )
 
 brms_mvn_2_args <- list(
-  formula = brms::bf(y ~ 1 + l1, family = brms::brmsfamily("gaussian", link = "identity"), center = FALSE),
+  formula = brms::bf(
+    y ~ 1 + l1,
+    family = brms::brmsfamily("gaussian", link = "identity"),
+    center = FALSE
+  ),
   data = data.frame(y = 1, l1 = 0),
-  prior = brms::prior(mixmvnorm(prior_w, prior_m, prior_sigma_L), class = b) + brms::prior(constant(1), class = sigma)
+  prior = brms::prior(mixmvnorm(prior_w, prior_m, prior_sigma_L), class = b) +
+    brms::prior(constant(1), class = sigma)
 )
 
 test_that("Multivariate normal (2D) is correct for brms sampled prior", {
