@@ -25,7 +25,16 @@ run_on_cran <- function() {
   return(TRUE)
 }
 
-oc2S_normal_MC <- function(prior1, prior2, N1, N2, theta1, theta2, pcrit = 0.975, qcrit = 0) {
+oc2S_normal_MC <- function(
+  prior1,
+  prior2,
+  N1,
+  N2,
+  theta1,
+  theta2,
+  pcrit = 0.975,
+  qcrit = 0
+) {
   mean_sd1 <- sigma(prior1) / sqrt(N1)
   mean_sd2 <- sigma(prior2) / sqrt(N2)
 
@@ -73,7 +82,15 @@ test_that("Type I error is matching between MC and analytical computations in th
   skip_on_cran()
 
   x <- c(-2, 0)
-  alpha <- oc2S(prior1, prior2, N1, N2, decision2S(pcrit, qcrit), sigma1 = sigma(prior1), sigma2 = sigma(prior2))(x, x)
+  alpha <- oc2S(
+    prior1,
+    prior2,
+    N1,
+    N2,
+    decision2S(pcrit, qcrit),
+    sigma1 = sigma(prior1),
+    sigma2 = sigma(prior2)
+  )(x, x)
   alphaMC <- Voc2S_normal_MC(prior1, prior2, N1, N2, x, x, pcrit, qcrit)
   res <- 100 * abs(alpha - alphaMC)
   expect_equal(sum(res > 2), 0)
@@ -84,8 +101,25 @@ test_that("Type I error is matching between MC and analytical computations in th
 test_that("Power is matching between MC and analytical computations in the normal mixture case", {
   skip_on_cran()
 
-  power <- oc2S(prior1, prior2, N1, N2, decision2S(pcrit, qcrit), sigma1 = sigma(prior1), sigma2 = sigma(prior2))(theta1, theta2)
-  powerMC <- oc2S_normal_MC(prior1, prior2, N1, N2, theta1, theta2, pcrit, qcrit)
+  power <- oc2S(
+    prior1,
+    prior2,
+    N1,
+    N2,
+    decision2S(pcrit, qcrit),
+    sigma1 = sigma(prior1),
+    sigma2 = sigma(prior2)
+  )(theta1, theta2)
+  powerMC <- oc2S_normal_MC(
+    prior1,
+    prior2,
+    N1,
+    N2,
+    theta1,
+    theta2,
+    pcrit,
+    qcrit
+  )
   res <- 100 * abs(power - powerMC)
   expect_equal(sum(res > 2), 0)
 })
@@ -124,10 +158,28 @@ test_that("Gsponer et al. results match (normal end-point)", {
   ## spline function
 
   ## Table 1, probability for interim for success
-  oc$success <- oc2S(priorP, priorT, nP1, nT1, successCrit, Ngrid = 1, sigma1 = sigmaFixed, sigma2 = sigmaFixed)(-49, -49 - oc$delta)
+  oc$success <- oc2S(
+    priorP,
+    priorT,
+    nP1,
+    nT1,
+    successCrit,
+    Ngrid = 1,
+    sigma1 = sigmaFixed,
+    sigma2 = sigmaFixed
+  )(-49, -49 - oc$delta)
 
   ## Table 1, probability for interim for futility
-  oc$futile <- oc2S(priorP, priorT, nP1, nT1, futilityCrit, Ngrid = 1, sigma1 = sigmaFixed, sigma2 = sigmaFixed)(-49, -49 - oc$delta)
+  oc$futile <- oc2S(
+    priorP,
+    priorT,
+    nP1,
+    nT1,
+    futilityCrit,
+    Ngrid = 1,
+    sigma1 = sigmaFixed,
+    sigma2 = sigmaFixed
+  )(-49, -49 - oc$delta)
 
   ## Table 1, first three columns, page 74
   oc[-1] <- lapply(100 * oc[-1], round, 1)
@@ -164,10 +216,13 @@ test_that("Ensure that repeated oc2S evaluation works for normal case", {
   successCrit <- decision2S(c(0.9), c(0), FALSE)
 
   interim_CP <- oc2S(
-    postT_interim, postP_interim,
-    n_ia_to_final, n_ia_to_final,
+    postT_interim,
+    postP_interim,
+    n_ia_to_final,
+    n_ia_to_final,
     successCrit,
-    sigma1 = samp_sigma, sigma2 = samp_sigma
+    sigma1 = samp_sigma,
+    sigma2 = samp_sigma
   )
 
   cpd_ia <- interim_CP(obs_T, obs_P)
@@ -179,13 +234,21 @@ test_that("Ensure that repeated oc2S evaluation works for normal case", {
   ## check that when calculating directly that the results
   ## are close enough
   interim_CPalt <- oc2S(
-    postT_interim, postP_interim,
-    n_ia_to_final, n_ia_to_final,
+    postT_interim,
+    postP_interim,
+    n_ia_to_final,
+    n_ia_to_final,
     successCrit,
-    sigma1 = samp_sigma, sigma2 = samp_sigma
+    sigma1 = samp_sigma,
+    sigma2 = samp_sigma
   )
   cpd_ia2alt <- interim_CPalt(theta_ctl + delta, theta_ctl)
-  expect_number(abs(cpd_ia2 - cpd_ia2alt), lower = 0, upper = 1E-3, finite = TRUE)
+  expect_number(
+    abs(cpd_ia2 - cpd_ia2alt),
+    lower = 0,
+    upper = 1E-3,
+    finite = TRUE
+  )
 })
 
 ## test against Schmidli et. al, "Robust Meta-Analytic-Predictive
@@ -195,15 +258,37 @@ test_that("Schmidli et al. results (binary end-point)", {
 
   ocRef_inf <- expand.grid(pc = seq(0.1, 0.6, by = 0.1), delta = c(0, 0.3))
   ocRef_inf$ref <- c(
-    0, 1.6, 6.1, 13.7, 26.0, 44.4 ## beta/delta=0
-    , 81.6, 87.8, 93.4, 97.9, 99.6, 100.0 ## beta/delta=0.3
-  ) / 100
+    0,
+    1.6,
+    6.1,
+    13.7,
+    26.0,
+    44.4, ## beta/delta=0
+    81.6,
+    87.8,
+    93.4,
+    97.9,
+    99.6,
+    100.0 ## beta/delta=0.3
+  ) /
+    100
 
   ocRef_uni <- expand.grid(pc = seq(0.1, 0.6, by = 0.1), delta = c(0, 0.3))
   ocRef_uni$ref <- c(
-    1.8, 2.3, 2.4, 2.6, 2.8, 2.6 ## unif/delta=0
-    , 89.7, 82.1, 79.5, 79.5, 81.9, 89.8 ## unif/delta=0.3
-  ) / 100
+    1.8,
+    2.3,
+    2.4,
+    2.6,
+    2.8,
+    2.6, ## unif/delta=0
+    89.7,
+    82.1,
+    79.5,
+    79.5,
+    81.9,
+    89.8 ## unif/delta=0.3
+  ) /
+    100
   dec <- decision2S(0.975, 0, lower.tail = FALSE)
 
   N <- 40
@@ -268,9 +353,21 @@ decB <- decision2S(1 - alpha, 0, lower.tail = FALSE)
 beta_prior <- mixbeta(c(1, 1, 1))
 if (!run_on_cran()) {
   design_binary <- oc2S(beta_prior, beta_prior, 100, 100, dec)
-  boundary_design_binary <- decision2S_boundary(beta_prior, beta_prior, 100, 100, dec)
+  boundary_design_binary <- decision2S_boundary(
+    beta_prior,
+    beta_prior,
+    100,
+    100,
+    dec
+  )
   design_binaryB <- oc2S(beta_prior, beta_prior, 100, 100, decB)
-  boundary_design_binaryB <- decision2S_boundary(beta_prior, beta_prior, 100, 100, decB)
+  boundary_design_binaryB <- decision2S_boundary(
+    beta_prior,
+    beta_prior,
+    100,
+    100,
+    decB
+  )
 } else {
   design_binary <- function(...) {
     return(0.1)
@@ -301,11 +398,23 @@ test_that("Binary crticial value, lower.tail=FALSE", {
 })
 test_that("Binary boundary case, lower.tail=TRUE", {
   skip_on_cran()
-  expect_numeric(design_binary(1, 1), lower = 0, upper = 1, finite = TRUE, any.missing = FALSE)
+  expect_numeric(
+    design_binary(1, 1),
+    lower = 0,
+    upper = 1,
+    finite = TRUE,
+    any.missing = FALSE
+  )
 })
 test_that("Binary boundary case, lower.tail=FALSE", {
   skip_on_cran()
-  expect_numeric(design_binaryB(0, 0), lower = 0, upper = 1, finite = TRUE, any.missing = FALSE)
+  expect_numeric(
+    design_binaryB(0, 0),
+    lower = 0,
+    upper = 1,
+    finite = TRUE,
+    any.missing = FALSE
+  )
 })
 
 ## check case where decision never changes due to prior being too
@@ -315,8 +424,20 @@ beta_prior1 <- mixbeta(c(1, 0.9, 1000), param = "mn")
 beta_prior2 <- mixbeta(c(1, 0.1, 1000), param = "mn")
 design_lower <- oc2S(beta_prior1, beta_prior2, 20, 20, dec) ## always 0
 design_upper <- oc2S(beta_prior1, beta_prior2, 20, 20, decB) ## always 1
-boundary_design_lower <- decision2S_boundary(beta_prior1, beta_prior2, 20, 20, dec) ## always 0
-boundary_design_upper <- decision2S_boundary(beta_prior1, beta_prior2, 20, 20, decB) ## always 1
+boundary_design_lower <- decision2S_boundary(
+  beta_prior1,
+  beta_prior2,
+  20,
+  20,
+  dec
+) ## always 0
+boundary_design_upper <- decision2S_boundary(
+  beta_prior1,
+  beta_prior2,
+  20,
+  20,
+  decB
+) ## always 1
 
 test_that("Binary case, no decision change, lower.tail=TRUE, critical value", {
   skip_on_cran()
@@ -339,8 +460,20 @@ test_that("Binary case, no decision change, lower.tail=FALSE, frequency=1", {
 if (!run_on_cran()) {
   design_lower_rev <- oc2S(beta_prior2, beta_prior1, 20, 20, dec) ## always 1
   design_upper_rev <- oc2S(beta_prior2, beta_prior1, 20, 20, decB) ## always 0
-  boundary_design_lower_rev <- decision2S_boundary(beta_prior2, beta_prior1, 20, 20, dec) ## always 1
-  boundary_design_upper_rev <- decision2S_boundary(beta_prior2, beta_prior1, 20, 20, decB) ## always 0
+  boundary_design_lower_rev <- decision2S_boundary(
+    beta_prior2,
+    beta_prior1,
+    20,
+    20,
+    dec
+  ) ## always 1
+  boundary_design_upper_rev <- decision2S_boundary(
+    beta_prior2,
+    beta_prior1,
+    20,
+    20,
+    decB
+  ) ## always 0
 } else {
   design_lower_rev <- function(...) {
     return(1)
@@ -374,25 +507,55 @@ test_that("Binary case, no decision change (reversed), lower.tail=FALSE, frequen
 })
 test_that("Binary case, log-link", {
   skip_on_cran()
-  success <- decision2S(pc = c(0.90, 0.50), qc = c(log(1), log(0.50)), lower.tail = TRUE, link = "log")
-  prior_pbo <- mixbeta(inf1 = c(0.60, 19, 29), inf2 = c(0.30, 4, 5), rob = c(0.10, 1, 1))
+  success <- decision2S(
+    pc = c(0.90, 0.50),
+    qc = c(log(1), log(0.50)),
+    lower.tail = TRUE,
+    link = "log"
+  )
+  prior_pbo <- mixbeta(
+    inf1 = c(0.60, 19, 29),
+    inf2 = c(0.30, 4, 5),
+    rob = c(0.10, 1, 1)
+  )
   prior_trt <- mixbeta(c(1, 1 / 3, 1 / 3))
   n_trt <- 50
   n_pbo <- 20
   design_suc <- oc2S(prior_trt, prior_pbo, n_trt, n_pbo, success)
   theta <- seq(0, 1, by = 0.1)
-  expect_numeric(design_suc(theta, theta), lower = 0, upper = 1, finite = TRUE, any.missing = FALSE)
+  expect_numeric(
+    design_suc(theta, theta),
+    lower = 0,
+    upper = 1,
+    finite = TRUE,
+    any.missing = FALSE
+  )
 })
 test_that("Binary case, logit-link", {
   skip_on_cran()
-  success <- decision2S(pc = c(0.90, 0.50), qc = c(log(1), log(0.50)), lower.tail = TRUE, link = "logit")
-  prior_pbo <- mixbeta(inf1 = c(0.60, 19, 29), inf2 = c(0.30, 4, 5), rob = c(0.10, 1, 1))
+  success <- decision2S(
+    pc = c(0.90, 0.50),
+    qc = c(log(1), log(0.50)),
+    lower.tail = TRUE,
+    link = "logit"
+  )
+  prior_pbo <- mixbeta(
+    inf1 = c(0.60, 19, 29),
+    inf2 = c(0.30, 4, 5),
+    rob = c(0.10, 1, 1)
+  )
   prior_trt <- mixbeta(c(1, 1 / 3, 1 / 3))
   n_trt <- 50
   n_pbo <- 20
   design_suc <- oc2S(prior_trt, prior_pbo, n_trt, n_pbo, success)
   theta <- seq(0, 1, by = 0.1)
-  expect_numeric(design_suc(theta, theta), lower = 0, upper = 1, finite = TRUE, any.missing = FALSE)
+  expect_numeric(
+    design_suc(theta, theta),
+    lower = 0,
+    upper = 1,
+    finite = TRUE,
+    any.missing = FALSE
+  )
 })
 
 ## check approximate method
@@ -425,8 +588,20 @@ gamma_prior <- mixgamma(c(1, 2, 2))
 
 design_poisson <- oc2S(gamma_prior, gamma_prior, 100, 100, dec)
 design_poissonB <- oc2S(gamma_prior, gamma_prior, 100, 100, decB)
-boundary_design_poisson <- decision2S_boundary(gamma_prior, gamma_prior, 100, 100, dec)
-boundary_design_poissonB <- decision2S_boundary(gamma_prior, gamma_prior, 100, 100, decB)
+boundary_design_poisson <- decision2S_boundary(
+  gamma_prior,
+  gamma_prior,
+  100,
+  100,
+  dec
+)
+boundary_design_poissonB <- decision2S_boundary(
+  gamma_prior,
+  gamma_prior,
+  100,
+  100,
+  decB
+)
 posterior_poisson <- function(m) postmix(gamma_prior, m = m / 100, n = 100)
 lambda_test <- seq(0.5, 1.3, by = 0.1)
 test_that("Poisson type I error rate", {
@@ -450,7 +625,6 @@ test_that("Poisson crticial value, lower.tail=FALSE", {
 ##              expect_true(sum(is.na(design_poisson(theta1=c(0.01, 1), y2=70:90)) ) == 0)
 ##          })
 
-
 test_that("Normal OC 2-sample case works for n2=0, crohn-1", {
   crohn_sigma <- 88
 
@@ -465,11 +639,22 @@ test_that("Normal OC 2-sample case works for n2=0, crohn-1", {
   n_act <- 40
   ## n_pbo <- 20
 
-  design_noprior_b <- oc2S(weak_prior, map, n_act, 0, poc,
-    sigma1 = crohn_sigma, sigma2 = crohn_sigma
+  design_noprior_b <- oc2S(
+    weak_prior,
+    map,
+    n_act,
+    0,
+    poc,
+    sigma1 = crohn_sigma,
+    sigma2 = crohn_sigma
   )
 
-  expect_numeric(design_noprior_b(-20, -30), lower = 0, upper = 1, any.missing = FALSE)
+  expect_numeric(
+    design_noprior_b(-20, -30),
+    lower = 0,
+    upper = 1,
+    any.missing = FALSE
+  )
 })
 
 test_that("Normal OC 2-sample case works for n2=0, crohn-2", {
@@ -486,11 +671,22 @@ test_that("Normal OC 2-sample case works for n2=0, crohn-2", {
   n_act <- 40
   ## n_pbo <- 20
 
-  design_noprior_b <- oc2S(weak_prior, map, n_act, 0, poc,
-    sigma1 = crohn_sigma, sigma2 = crohn_sigma
+  design_noprior_b <- oc2S(
+    weak_prior,
+    map,
+    n_act,
+    0,
+    poc,
+    sigma1 = crohn_sigma,
+    sigma2 = crohn_sigma
   )
 
-  expect_numeric(design_noprior_b(-20, -30), lower = 0, upper = 1, any.missing = FALSE)
+  expect_numeric(
+    design_noprior_b(-20, -30),
+    lower = 0,
+    upper = 1,
+    any.missing = FALSE
+  )
 })
 
 test_that("Normal OC 2-sample avoids undefined behavior, example 1", {
@@ -499,24 +695,60 @@ test_that("Normal OC 2-sample avoids undefined behavior, example 1", {
   sigma_ref <- 3.2
   ## map_ref <- mixnorm(c(0.51, -2.1, 0.39), c(0.42, -2.1, 0.995), c(0.06, -1.99, 2.32), sigma=sigma_ref)
   ## chagned so that weights sum to 1
-  map_ref <- mixnorm(c(0.52, -2.1, 0.39), c(0.42, -2.1, 0.995), c(0.06, -1.99, 2.32), sigma = sigma_ref)
+  map_ref <- mixnorm(
+    c(0.52, -2.1, 0.39),
+    c(0.42, -2.1, 0.995),
+    c(0.06, -1.99, 2.32),
+    sigma = sigma_ref
+  )
   prior_flat <- mixnorm(c(1, 0, 100), sigma = sigma_ref)
   alpha <- 0.05
   dec <- decision2S(1 - alpha, 0, lower.tail = FALSE)
   n <- 58
   k <- 2
-  design_map <- oc2S(prior_flat, map_ref, n, n / k, dec, sigma1 = sigma_ref, sigma2 = sigma_ref)
-  design_map_2 <- oc2S(prior_flat, map_ref, n, n / k, dec, sigma1 = sigma_ref, sigma2 = sigma_ref)
+  design_map <- oc2S(
+    prior_flat,
+    map_ref,
+    n,
+    n / k,
+    dec,
+    sigma1 = sigma_ref,
+    sigma2 = sigma_ref
+  )
+  design_map_2 <- oc2S(
+    prior_flat,
+    map_ref,
+    n,
+    n / k,
+    dec,
+    sigma1 = sigma_ref,
+    sigma2 = sigma_ref
+  )
 
   x <- seq(-2.6, -1.6, by = 0.1)
   expect_numeric(design_map(x, x), lower = 0, upper = 1, any.missing = FALSE)
   expect_silent(design_map(-3, -4))
   expect_numeric(design_map(-3, -4), lower = 0, upper = 1, any.missing = FALSE)
   expect_numeric(design_map(-3, 4), lower = 0, upper = 1, any.missing = FALSE)
-  expect_numeric(design_map(-1.6, -1.6), lower = 0, upper = 1, any.missing = FALSE)
+  expect_numeric(
+    design_map(-1.6, -1.6),
+    lower = 0,
+    upper = 1,
+    any.missing = FALSE
+  )
 
-  expect_numeric(design_map_2(-3, -4), lower = 0, upper = 1, any.missing = FALSE)
+  expect_numeric(
+    design_map_2(-3, -4),
+    lower = 0,
+    upper = 1,
+    any.missing = FALSE
+  )
   expect_numeric(design_map_2(-3, 4), lower = 0, upper = 1, any.missing = FALSE)
-  expect_numeric(design_map_2(-1.6, -1.6), lower = 0, upper = 1, any.missing = FALSE)
+  expect_numeric(
+    design_map_2(-1.6, -1.6),
+    lower = 0,
+    upper = 1,
+    any.missing = FALSE
+  )
   expect_numeric(design_map_2(x, x), lower = 0, upper = 1, any.missing = FALSE)
 })
