@@ -23,7 +23,9 @@ test_that("variances have correct ordering", {
   expect_true(all(pred_var_pred > tau_est))
 
   ## ensure that predictive has larger variance than the model estimate
-  expect_true(all(summary(pred_cov_link_pred)[, "sd"] > summary(pred_cov_link)[, "sd"]))
+  expect_true(all(
+    summary(pred_cov_link_pred)[, "sd"] > summary(pred_cov_link)[, "sd"]
+  ))
 })
 
 
@@ -34,7 +36,11 @@ test_that("correct # of new predictions are generated", {
 
 ## must have larger sd than between-trial alone (on link scale)
 test_that("predictive variances have correct ordering", {
-  pred_new_link <- predict(map, data.frame(country = "CH", study = 11), type = "link")
+  pred_new_link <- predict(
+    map,
+    data.frame(country = "CH", study = 11),
+    type = "link"
+  )
   tau_est <- summary(map)$tau[, "mean"]
   expect_true(summary(pred_new_link)[, "sd"] > tau_est)
 })
@@ -43,7 +49,12 @@ test_that("predictive variances have correct ordering", {
 ## the MAP must be numerically exactly the same. This ensures that per
 ## study the random effect is sampled just once in each iteration.
 test_that("predictive distributions for the same study & covariate must match exactly", {
-  trans_cov_new <- data.frame(study = "new", n = 50, r = 0, country = levels(trans_cov$country)[c(1, 1)])
+  trans_cov_new <- data.frame(
+    study = "new",
+    n = 50,
+    r = 0,
+    country = levels(trans_cov$country)[c(1, 1)]
+  )
   post_trans <- as.matrix(predict(map, newdata = trans_cov_new))
   expect_equal(post_trans[, 1], post_trans[, 2])
 })
@@ -66,7 +77,11 @@ test_that("mixfit for prediction handles response and link scale", {
   expect_true("betaMix" %in% class(pred_map[[1]]))
   expect_equal(ncol(pred_map[[1]]), 2)
 
-  pred_new_link <- predict(map, data.frame(country = "CH", study = 11), type = "link")
+  pred_new_link <- predict(
+    map,
+    data.frame(country = "CH", study = 11),
+    type = "link"
+  )
   pred_map_link <- mixfit(pred_new_link, Nc = 2)
 
   expect_true(is.list(pred_map_link))
@@ -87,7 +102,11 @@ test_that("combination of mixtures", {
 
 test_that("throws an error if more weights than mixtures given", {
   ## giving 3 weights but only 2 mixtures must not work
-  expect_error(mixcombine(bm, unif, weight = c(8, 1, 1)), "length(weight) not equal to length(comp)", fixed = TRUE)
+  expect_error(
+    mixcombine(bm, unif, weight = c(8, 1, 1)),
+    "length(weight) not equal to length(comp)",
+    fixed = TRUE
+  )
 })
 
 test_that("combination of normal mixtures without default sigma works", {
@@ -112,7 +131,11 @@ test_that("beta mixture is robustified with Beta(0.5,0.5)", {
 test_that("gamma mixture is robustified with n=1 equivalent prior", {
   m <- summary(gmnMix)["mean"]
   nr <- ncol(rgmnMix)
-  expect_equal(rgmnMix[[nr, rescale = TRUE]], mixgamma(c(1, m, 1), param = "mn"), ignore_attr = TRUE)
+  expect_equal(
+    rgmnMix[[nr, rescale = TRUE]],
+    mixgamma(c(1, m, 1), param = "mn"),
+    ignore_attr = TRUE
+  )
   expect_equal(rgmnMix[1, nr], 0.1)
 })
 
@@ -120,20 +143,32 @@ test_that("gamma mixture is robustified with n=5 equivalent prior", {
   m <- summary(gmnMix)["mean"]
   rgmnMix2 <- robustify(gmnMix, w = 0.1, n = 5, mean = 2)
   nr <- ncol(rgmnMix2)
-  expect_equal(rgmnMix2[[nr, rescale = TRUE]], mixgamma(c(1, m, 5), param = "mn"), ignore_attr = TRUE)
+  expect_equal(
+    rgmnMix2[[nr, rescale = TRUE]],
+    mixgamma(c(1, m, 5), param = "mn"),
+    ignore_attr = TRUE
+  )
   expect_equal(rgmnMix2[1, nr], 0.1)
 })
 
 test_that("normal mixture is robustified with n=1 equivalent prior", {
   nr <- ncol(rnMix)
-  expect_equal(rnMix[[nr, rescale = TRUE]], mixnorm(c(1, 0, 1), param = "mn", sigma = sigma(nm)), ignore_attr = TRUE)
+  expect_equal(
+    rnMix[[nr, rescale = TRUE]],
+    mixnorm(c(1, 0, 1), param = "mn", sigma = sigma(nm)),
+    ignore_attr = TRUE
+  )
   expect_equal(rnMix[1, nr], 0.1)
 })
 
 test_that("normal mixture is robustified with n=5 equivalent prior", {
   rnMix2 <- robustify(nm, w = 0.1, mean = 0, n = 5, sigma = sigma(nm))
   nr <- ncol(rnMix2)
-  expect_equal(rnMix2[[nr, rescale = TRUE]], mixnorm(c(1, 0, 5), param = "mn", sigma = sigma(nm)), ignore_attr = TRUE)
+  expect_equal(
+    rnMix2[[nr, rescale = TRUE]],
+    mixnorm(c(1, 0, 5), param = "mn", sigma = sigma(nm)),
+    ignore_attr = TRUE
+  )
   expect_equal(rnMix2[1, nr], 0.1)
 })
 
@@ -156,26 +191,43 @@ test_that("ess elir for beta mixtures gives a warning for a<1 & b<1 densities",
   unconstrain1 <- mixbeta(c(0.95, 10, 5), c(0.05, 0.9, 2))
   unconstrain2 <- mixbeta(c(0.95, 10, 5), c(0.05, 2, 0.9))
 
-  expect_error(ess(unconstrain1, "elir"), "At least one parameter of the beta mixtures is less than 1")
-  expect_error(ess(unconstrain2, "elir"), "At least one parameter of the beta mixtures is less than 1")
+  expect_error(
+    ess(unconstrain1, "elir"),
+    "At least one parameter of the beta mixtures is less than 1"
+  )
+  expect_error(
+    ess(unconstrain2, "elir"),
+    "At least one parameter of the beta mixtures is less than 1"
+  )
 
   ## this one can trigger errors if the integration is not setup properly
   constrained <- mixbeta(c(0.48, 1, 11), c(0.34, 6.9, 173), c(0.18, 1.0, 1.13))
-  expect_numeric(ess(constrained, "elir"), lower = 0, finite = TRUE, any.missing = FALSE, len = 1)
+  expect_numeric(
+    ess(constrained, "elir"),
+    lower = 0,
+    finite = TRUE,
+    any.missing = FALSE,
+    len = 1
+  )
 })
 
 test_that("conjugate normal case matches canonical formula", {
   s <- 2
   sigma_data <- 4
   nprior <- mixnorm(c(1, -1, s), sigma = sigma_data)
-  nprior_ess <- sigma_data^2/s^2
+  nprior_ess <- sigma_data^2 / s^2
   expect_equal(ess(nprior, "moment", sigma = sigma_data), nprior_ess)
-  expect_equal(ess(nprior, "morita", sigma = sigma_data, s=Inf), nprior_ess)
+  expect_equal(ess(nprior, "morita", sigma = sigma_data, s = Inf), nprior_ess)
   expect_equal(ess(nprior, "elir", sigma = sigma_data), nprior_ess)
 })
 
 test_that("ess elir for normal mixtures returns correct values", {
-  mix <- mixnorm(inf1 = c(0.5026, -191.1869, 127.4207), inf2 = c(0.2647, -187.5895, 31.6130), inf3 = c(0.2326, -184.7445, 345.3849), sigma = 270.4877)
+  mix <- mixnorm(
+    inf1 = c(0.5026, -191.1869, 127.4207),
+    inf2 = c(0.2647, -187.5895, 31.6130),
+    inf3 = c(0.2326, -184.7445, 345.3849),
+    sigma = 270.4877
+  )
   expect_gt(ess(mix, sigma = 270.4877), 0)
 })
 
@@ -184,7 +236,7 @@ test_that("moment matching for beta mixtures is correct", {
 })
 
 test_that("beta mix ess works when run through sapply", {
-  expect_numeric(sapply(X = list(bmix), FUN=ess))
+  expect_numeric(sapply(X = list(bmix), FUN = ess))
 })
 
 test_that("normal mixtures have reference scale used correctly", {
@@ -228,7 +280,7 @@ test_that("gamma mixtures have likelihood property respected", {
 })
 
 test_that("gamma mix ess works when run through sapply", {
-  expect_numeric(sapply(X = list(gmix), FUN=ess))
+  expect_numeric(sapply(X = list(gmix), FUN = ess))
 })
 
 test_that("gamma 1-component density gives canonical results", {
@@ -296,19 +348,44 @@ elir_predictive_consistent <- function(dens, m, Nsim, seed, stat, ...) {
 test_that("ESS elir is predictively consistent for normal mixtures", {
   skip_on_cran()
   nmix <- mixnorm(rob = c(0.5, 0, 2), inf = c(0.5, 3, 4), sigma = 10)
-  elir_predictive_consistent(nmix, m = 3E2, Nsim = 1E3, seed = 3435, stat = "m", se = 10 / sqrt(3E2))
+  elir_predictive_consistent(
+    nmix,
+    m = 3E2,
+    Nsim = 1E3,
+    seed = 3435,
+    stat = "m",
+    se = 10 / sqrt(3E2)
+  )
 })
 
 test_that("ESS elir is predictively consistent for beta mixtures", {
   skip_on_cran()
   bmix <- mixbeta(rob = c(0.2, 1, 1), inf = c(0.8, 10, 2))
-  elir_predictive_consistent(bmix, m = 1E2, Nsim = 1E3, seed = 355435, stat = "r", n = 1E2)
+  elir_predictive_consistent(
+    bmix,
+    m = 1E2,
+    Nsim = 1E3,
+    seed = 355435,
+    stat = "r",
+    n = 1E2
+  )
 })
 
 test_that("ESS elir is predictively consistent for gamma mixtures (Poisson likelihood)", {
   skip_on_cran()
-  gmixP <- mixgamma(rob = c(0.3, 20, 4), inf = c(0.7, 50, 10), likelihood = "poisson")
-  elir_predictive_consistent(gmixP, m = 1E2, Nsim = 1E3, seed = 355435, stat = "m", n = 1E2)
+  gmixP <- mixgamma(
+    rob = c(0.3, 20, 4),
+    inf = c(0.7, 50, 10),
+    likelihood = "poisson"
+  )
+  elir_predictive_consistent(
+    gmixP,
+    m = 1E2,
+    Nsim = 1E3,
+    seed = 355435,
+    stat = "m",
+    n = 1E2
+  )
 })
 
 test_that("ess elir for problematic beta mixtures gives correct result 1", {
@@ -317,57 +394,126 @@ test_that("ess elir for problematic beta mixtures gives correct result 1", {
   ## Error in if (all(dgl < 0) || all(dgl > 0)) { :
   ##   missing value where TRUE/FALSE needed
 
-  mixmat <- matrix(c(
-    0.06429517, 0.03301215, 0.00269268, 0.90000000,
-    437.32302999, 64.04211307, 5.92543558, 1.00000000,
-    10.71709277, 2.14157953, 1.00000001, 1.00000000
-  ), byrow = TRUE, ncol = 4)
+  mixmat <- matrix(
+    c(
+      0.06429517,
+      0.03301215,
+      0.00269268,
+      0.90000000,
+      437.32302999,
+      64.04211307,
+      5.92543558,
+      1.00000000,
+      10.71709277,
+      2.14157953,
+      1.00000001,
+      1.00000000
+    ),
+    byrow = TRUE,
+    ncol = 4
+  )
 
   mixb <- do.call(mixbeta, apply(mixmat, 2, c, simplify = FALSE))
 
-  expect_double(ess(mixb), lower = 0, finite = TRUE, any.missing = FALSE, len = 1)
+  expect_double(
+    ess(mixb),
+    lower = 0,
+    finite = TRUE,
+    any.missing = FALSE,
+    len = 1
+  )
 })
 
 test_that("ess elir for problematic beta mixtures gives correct result 2", {
-  mixmat <- matrix(c(
-    0.7237396, 0.1665037, 0.1097567,
-    53.3721902, 44.3894573, 9.8097062,
-    1.4301638, 4.3842200, 1.8492197
-  ), byrow = TRUE, ncol = 3)
+  mixmat <- matrix(
+    c(
+      0.7237396,
+      0.1665037,
+      0.1097567,
+      53.3721902,
+      44.3894573,
+      9.8097062,
+      1.4301638,
+      4.3842200,
+      1.8492197
+    ),
+    byrow = TRUE,
+    ncol = 3
+  )
 
   mixb <- do.call(mixbeta, apply(mixmat, 2, c, simplify = FALSE))
 
-  expect_double(ess(robustify(mixb, 0.05, 0.5)), lower = 0, finite = TRUE, any.missing = FALSE, len = 1)
-  expect_double(ess(robustify(mixb, 0.95, 0.5)), lower = 0, finite = TRUE, any.missing = FALSE, len = 1)
+  expect_double(
+    ess(robustify(mixb, 0.05, 0.5)),
+    lower = 0,
+    finite = TRUE,
+    any.missing = FALSE,
+    len = 1
+  )
+  expect_double(
+    ess(robustify(mixb, 0.95, 0.5)),
+    lower = 0,
+    finite = TRUE,
+    any.missing = FALSE,
+    len = 1
+  )
 })
 
 
 test_that("ess elir for problematic beta mixtures gives warning", {
-  mixmat1 <- matrix(c(
-    0.6092774, 0.2337629, 0.1569597,
-    1.0000000, 1.2672179, 3.3856153,
-    11.8465288, 1.2389927, 7.0191159
-  ), byrow = TRUE, ncol = 3)
-
+  mixmat1 <- matrix(
+    c(
+      0.6092774,
+      0.2337629,
+      0.1569597,
+      1.0000000,
+      1.2672179,
+      3.3856153,
+      11.8465288,
+      1.2389927,
+      7.0191159
+    ),
+    byrow = TRUE,
+    ncol = 3
+  )
 
   mixb1 <- do.call(mixbeta, apply(mixmat1, 2, c, simplify = FALSE))
 
   ## in case one of the coefficients of a and b is 1, then we can
   ## get negative results... which are unreliable to the user hopefully
   expect_warning(ess(mixb1))
-  expect_double(suppressWarnings(ess(mixb1)), finite = TRUE,
-                any.missing = FALSE, len = 1)
+  expect_double(
+    suppressWarnings(ess(mixb1)),
+    finite = TRUE,
+    any.missing = FALSE,
+    len = 1
+  )
 
-  mixmat2 <- matrix(c(
-    0.6051804, 0.2324492, 0.1623704,
-    1.0210697, 1.1955047, 3.1342298,
-    11.5485831, 1.0831573, 6.7636286
-  ), byrow = TRUE, ncol = 3)
+  mixmat2 <- matrix(
+    c(
+      0.6051804,
+      0.2324492,
+      0.1623704,
+      1.0210697,
+      1.1955047,
+      3.1342298,
+      11.5485831,
+      1.0831573,
+      6.7636286
+    ),
+    byrow = TRUE,
+    ncol = 3
+  )
 
   mixb2 <- do.call(mixbeta, apply(mixmat2, 2, c, simplify = FALSE))
 
-  expect_double(ess(mixb2), lower = 0, finite = TRUE, any.missing = FALSE,
-                len = 1)
+  expect_double(
+    ess(mixb2),
+    lower = 0,
+    finite = TRUE,
+    any.missing = FALSE,
+    len = 1
+  )
 })
 
 test_that("BinaryExactCI has correct boundary behavior", {
@@ -410,22 +556,58 @@ test_that("ess for a normal density with binomial family under a logit link give
   m1 <- 0
   s1 <- 2 / sqrt(10)
   prior_norm1 <- mixnorm(c(1, m1, s1), sigma = 2)
-  expect_equal(ess(prior_norm1, "elir", family = binomial, sigma = 2), ess_elir_binomial_logit(m1, s1), tolerance = 1E-4)
-  expect_equal(ess(prior_norm1, "moment", family = binomial, sigma = 2), ess_elir_binomial_logit(m1, s1), tolerance = 1E-4)
-  expect_equal(ess(prior_norm1, "morita", family = binomial, sigma = 2, s = Inf), pe_ess_binomial_logit(m1, s1), tolerance = 1E-4)
+  expect_equal(
+    ess(prior_norm1, "elir", family = binomial, sigma = 2),
+    ess_elir_binomial_logit(m1, s1),
+    tolerance = 1E-4
+  )
+  expect_equal(
+    ess(prior_norm1, "moment", family = binomial, sigma = 2),
+    ess_elir_binomial_logit(m1, s1),
+    tolerance = 1E-4
+  )
+  expect_equal(
+    ess(prior_norm1, "morita", family = binomial, sigma = 2, s = Inf),
+    pe_ess_binomial_logit(m1, s1),
+    tolerance = 1E-4
+  )
 
   m2 <- 2
   s2 <- 2 / sqrt(100)
   prior_norm2a <- mixnorm(c(1, m2, s2), sigma = 2)
-  expect_equal(ess(prior_norm2a, "elir", family = binomial, sigma = 2), ess_elir_binomial_logit(m2, s2), tolerance = 1E-4)
-  expect_equal(ess(prior_norm2a, "moment", family = binomial, sigma = 2), ess_elir_binomial_logit(m2, s2), tolerance = 1E-4)
-  expect_equal(ess(prior_norm2a, "morita", family = binomial, sigma = 2, s = Inf), pe_ess_binomial_logit(m2, s2), tolerance = 1E-4)
+  expect_equal(
+    ess(prior_norm2a, "elir", family = binomial, sigma = 2),
+    ess_elir_binomial_logit(m2, s2),
+    tolerance = 1E-4
+  )
+  expect_equal(
+    ess(prior_norm2a, "moment", family = binomial, sigma = 2),
+    ess_elir_binomial_logit(m2, s2),
+    tolerance = 1E-4
+  )
+  expect_equal(
+    ess(prior_norm2a, "morita", family = binomial, sigma = 2, s = Inf),
+    pe_ess_binomial_logit(m2, s2),
+    tolerance = 1E-4
+  )
 
   ## sigma does not play a role here
   prior_norm2b <- mixnorm(c(1, m2, s2), sigma = 4)
-  expect_equal(ess(prior_norm2b, "elir", family = binomial, sigma = 4), ess_elir_binomial_logit(m2, s2), tolerance = 1E-4)
-  expect_equal(ess(prior_norm2b, "moment", family = binomial, sigma = 4), ess_elir_binomial_logit(m2, s2), tolerance = 1E-4)
-  expect_equal(ess(prior_norm2b, "morita", family = binomial, sigma = 4, s = Inf), pe_ess_binomial_logit(m2, s2), tolerance = 1E-4)
+  expect_equal(
+    ess(prior_norm2b, "elir", family = binomial, sigma = 4),
+    ess_elir_binomial_logit(m2, s2),
+    tolerance = 1E-4
+  )
+  expect_equal(
+    ess(prior_norm2b, "moment", family = binomial, sigma = 4),
+    ess_elir_binomial_logit(m2, s2),
+    tolerance = 1E-4
+  )
+  expect_equal(
+    ess(prior_norm2b, "morita", family = binomial, sigma = 4, s = Inf),
+    pe_ess_binomial_logit(m2, s2),
+    tolerance = 1E-4
+  )
 })
 
 
@@ -461,22 +643,58 @@ test_that("ess for a normal density with poisson family under a log link gives c
   m1 <- 0
   s1 <- 2 / sqrt(10)
   prior_norm1 <- mixnorm(c(1, m1, s1), sigma = 2)
-  expect_equal(ess(prior_norm1, "elir", family = poisson, sigma = 2), ess_elir_poisson_log(m1, s1), tolerance = 1E-4)
-  expect_equal(ess(prior_norm1, "moment", family = poisson, sigma = 2), ess_elir_poisson_log(m1, s1), tolerance = 1E-4)
-  expect_equal(ess(prior_norm1, "morita", family = poisson, sigma = 2, s = Inf), pe_ess_poisson_log(m1, s1), tolerance = 1E-4)
+  expect_equal(
+    ess(prior_norm1, "elir", family = poisson, sigma = 2),
+    ess_elir_poisson_log(m1, s1),
+    tolerance = 1E-4
+  )
+  expect_equal(
+    ess(prior_norm1, "moment", family = poisson, sigma = 2),
+    ess_elir_poisson_log(m1, s1),
+    tolerance = 1E-4
+  )
+  expect_equal(
+    ess(prior_norm1, "morita", family = poisson, sigma = 2, s = Inf),
+    pe_ess_poisson_log(m1, s1),
+    tolerance = 1E-4
+  )
 
   m2 <- 2
   s2 <- 2 / sqrt(100)
   prior_norm2a <- mixnorm(c(1, m2, s2), sigma = 2)
-  expect_equal(ess(prior_norm2a, "elir", family = poisson, sigma = 2), ess_elir_poisson_log(m2, s2), tolerance = 1E-4)
-  expect_equal(ess(prior_norm2a, "moment", family = poisson, sigma = 2), ess_elir_poisson_log(m2, s2), tolerance = 1E-4)
-  expect_equal(ess(prior_norm2a, "morita", family = poisson, sigma = 2, s = Inf), pe_ess_poisson_log(m2, s2), tolerance = 1E-4)
+  expect_equal(
+    ess(prior_norm2a, "elir", family = poisson, sigma = 2),
+    ess_elir_poisson_log(m2, s2),
+    tolerance = 1E-4
+  )
+  expect_equal(
+    ess(prior_norm2a, "moment", family = poisson, sigma = 2),
+    ess_elir_poisson_log(m2, s2),
+    tolerance = 1E-4
+  )
+  expect_equal(
+    ess(prior_norm2a, "morita", family = poisson, sigma = 2, s = Inf),
+    pe_ess_poisson_log(m2, s2),
+    tolerance = 1E-4
+  )
 
   ## sigma does not play a role here
   prior_norm2b <- mixnorm(c(1, m2, s2), sigma = 4)
-  expect_equal(ess(prior_norm2b, "elir", family = poisson, sigma = 4), ess_elir_poisson_log(m2, s2), tolerance = 1E-4)
-  expect_equal(ess(prior_norm2b, "moment", family = poisson, sigma = 4), ess_elir_poisson_log(m2, s2), tolerance = 1E-4)
-  expect_equal(ess(prior_norm2b, "morita", family = poisson, sigma = 4, s = Inf), pe_ess_poisson_log(m2, s2), tolerance = 1E-4)
+  expect_equal(
+    ess(prior_norm2b, "elir", family = poisson, sigma = 4),
+    ess_elir_poisson_log(m2, s2),
+    tolerance = 1E-4
+  )
+  expect_equal(
+    ess(prior_norm2b, "moment", family = poisson, sigma = 4),
+    ess_elir_poisson_log(m2, s2),
+    tolerance = 1E-4
+  )
+  expect_equal(
+    ess(prior_norm2b, "morita", family = poisson, sigma = 4, s = Inf),
+    pe_ess_poisson_log(m2, s2),
+    tolerance = 1E-4
+  )
 })
 
 test_that("ess for a beta mixture errors if a family is specified", {
@@ -484,5 +702,8 @@ test_that("ess for a beta mixture errors if a family is specified", {
 })
 
 test_that("ess for a gamma mixture errors if a family is specified", {
-  expect_error(ess(mixgamma(rob = c(0.3, 20, 4), inf = c(0.7, 50, 10)), family = poisson))
+  expect_error(ess(
+    mixgamma(rob = c(0.3, 20, 4), inf = c(0.7, 50, 10)),
+    family = poisson
+  ))
 })
